pub enum AnnotationAttr {
Global(Attribute),
Encoding(String),
}Expand description
An attribute of annotation element. Either one of the global Attributes, or encode
attribute.
Variants
Global(Attribute)
One of the global Attributes.
Encoding(String)
NOTE: Authors can use the encoding attribute to distinguish annotations for HTML integration point, clipboard copy, alternative rendering, etc. In particular, CSS can be used to render alternative annotations e.g.
/* Hide the annotated child. */
semantics > :first-child { display: none; }
/* Show all text annotations. */
semantics > annotation { display: inline; }
/* Show all HTML annotations. */
semantics > annotation-xml[encoding="text/html" i],
semantics > annotation-xml[encoding="application/xhtml+xml" i] {
display: inline-block;
}Trait Implementations
Sourceimpl Clone for AnnotationAttr
impl Clone for AnnotationAttr
Sourcefn clone(&self) -> AnnotationAttr
fn clone(&self) -> AnnotationAttr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AnnotationAttr
impl Debug for AnnotationAttr
impl Eq for AnnotationAttr
Sourceimpl From<Attribute> for AnnotationAttr
impl From<Attribute> for AnnotationAttr
Sourceimpl Ord for AnnotationAttr
impl Ord for AnnotationAttr
Sourcefn cmp(&self, other: &AnnotationAttr) -> Ordering
fn cmp(&self, other: &AnnotationAttr) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AnnotationAttr
impl PartialEq for AnnotationAttr
Sourcefn eq(&self, other: &AnnotationAttr) -> bool
fn eq(&self, other: &AnnotationAttr) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for AnnotationAttr
impl PartialOrd for AnnotationAttr
impl StructuralPartialEq for AnnotationAttr