pub struct Row { /* private fields */ }Expand description
The mrow element is used to group together any number of sub-expressions, usually consisting
of one or more mo elements acting as “operators” on one or more other expressions that are
their “operands”.
Implementations
Sourceimpl Row
impl Row
Sourcepub fn add_element(&mut self, el: impl Into<Element>)
pub fn add_element(&mut self, el: impl Into<Element>)
Add a single element.
Sourcepub fn add_elements(&mut self, el: impl IntoElements)
pub fn add_elements(&mut self, el: impl IntoElements)
Add multiple elements.
Sourcepub fn with_attr<I, A>(self, attr: I) -> Self
pub fn with_attr<I, A>(self, attr: I) -> Self
Create a new instance of Row with additional attributes.
Sourcepub fn attributes(&self) -> &[Attribute]
pub fn attributes(&self) -> &[Attribute]
Get a reference to all attributes of the Row element.