pub enum UnderOverAttr {
AccentUnder,
AccentOver,
Global(Attribute),
}Expand description
The munderover element accepts global attributes as well as accent and accentunder.
Similarly, the mover element (respectively munder element) accepts global attributes as
well as the accent attribute (respectively the accentunder attribute).
accent, accentunder attributes, if present, must have values that are booleans. If these
attributes are absent or invalid, they are treated as equal to false.
Variants
AccentUnder
Indicates whether the under script should be treated as an accent (i.e. drawn bigger and closer to the base expression).
AccentOver
Indicates whether the over script should be treated as an accent (i.e. drawn bigger and closer to the base expression).
Global(Attribute)
One of the global Attributes.